@@ -9,7 +9,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.UUID;
 
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
@@ -52,6 +51,7 @@ import com.netflix.astyanax.model.Row;
 import com.netflix.astyanax.model.Rows;
 import com.netflix.astyanax.query.PreparedIndexExpression;
 import com.netflix.astyanax.serializers.StringSerializer;
+import com.netflix.astyanax.util.RangeBuilder;
 /**
  * @author Massimiliano Assante ISTI-CNR
  * 
@@ -380,7 +380,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		}
 		else return false;
 	}
-	
+
 	/**
 	 * {@inheritDoc}
 	 */
@@ -1335,6 +1335,39 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		boolean updateCommentNoResult = updateFeedCommentsCount(toComment, true);
 		return updateCommentNoResult;
 	}
+	/**
+	 * {@inheritDoc}
+	 */
+	public Comment readCommentById(String commentId) throws CommentIDNotFoundException {
+		Comment toReturn = new Comment();
+		OperationResult<ColumnList<String>> result;
+		try {
+			result = conn.getKeyspace().prepareQuery(cf_Comments)
+					.getKey(commentId)
+					.execute();
+
+			ColumnList<String> columns = result.getResult();
+			if (columns.size() == 0) {
+				throw new CommentIDNotFoundException("The requested commentId: " + commentId + " is not existing");
+			}
+
+			toReturn.setKey(commentId);
+			toReturn.setText(columns.getColumnByName("Text").getStringValue());
+			toReturn.setFullName(columns.getColumnByName("FullName").getStringValue());
+			toReturn.setEdit(columns.getColumnByName("IsEdited").getBooleanValue());
+			toReturn.setFeedid(columns.getColumnByName("Feedid").getStringValue());
+			toReturn.setUserid(columns.getColumnByName("Userid").getStringValue());
+			toReturn.setTime(getDateFromTimeInMillis(columns.getColumnByName("Timestamp").getStringValue()));
+			toReturn.setThumbnailURL(columns.getColumnByName("ThumbnailURL").getStringValue());
+			if (columns.getColumnByName("LastEditTime") != null)
+				toReturn.setLastEditTime(getDateFromTimeInMillis(columns.getColumnByName("LastEditTime").getStringValue()));
+
+		} catch (ConnectionException e) {
+			e.printStackTrace();
+			return null;
+		}	
+		return toReturn;
+	}
 	/**
 	 * {@inheritDoc}
 	 */
@@ -1917,7 +1950,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 						toAdd.setName(col.getStringValue());
 					else if (col.getName().compareTo("description") == 0)
 						toAdd.setDescription(col.getStringValue());
-					else if (col.getName().compareTo("ThumbnailURL") == 0)
+					else if (col.getName().compareTo("thumbnailURL") == 0)
 						toAdd.setThumbnailURL(col.getStringValue());
 					else if (col.getName().compareTo("mimeType") == 0)
 						toAdd.setMimeType(col.getStringValue());
@@ -2304,9 +2337,25 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 	}
 
 
+	@Override
+	public List<String> getAllVREIds() throws ConnectionException{
 
+		List<String> ids = new ArrayList<>();
 
+		OperationResult<Rows<String, String>> rows = conn.getKeyspace().prepareQuery(cf_VRETline).getAllRows()
+				.withColumnRange(new RangeBuilder().setLimit(0).build())
+				.execute();
 
+		Rows<String, String> res = rows.getResult();
 
+		for (Row<String, String> row : res) {
+			ids.add(row.getKey());
+		}
+
+		_log.debug("VRE ids are " + ids);
+		
+		return ids;
+
+	}
 
 }
